@@ -5,8 +5,8 @@
 #'
 #' See examples for how to use custom algorithms and distance functions. The
 #' default clustering algorithms provided are:
-#' * "nmf": Nonnegative Matrix Factorization (using sequential coordinate-wise
-#'   descent or Lee's multiplicative algorithm; See Note for specifications.)
+#' * "nmf": Nonnegative Matrix Factorization (using Kullback-Leibler Divergence
+#' or Euclidean distance; See Note for specifications.)
 #' * "hc": Hierarchical Clustering
 #' * "diana": DIvisive ANAlysis Clustering
 #' * "km": K-Means Clustering
@@ -23,13 +23,13 @@
 #'
 #' The progress bar increments on every unit of `reps`.
 #'
-#' @note The `nmf.method` options are "scd" for sequential coordinate-wise
-#'   descent and "lee" for Lee's multiplicative algorithm. When "hdbscan" is
-#'   chosen as an algorithm to use, its results are excluded from the rest of
-#'   the consensus clusters. This is because there is no guarantee that the
-#'   cluster assignment will have every sample clustered; more often than not
-#'   there will be noise points or outliers. In addition, the number of distinct
-#'   clusters may not even be equal to `nk`.
+#' @note The `nmf.method` options are "brunet" (Kullback-Leibler Divergence) and
+#'   "lee" (Euclidean distance). When "hdbscan" is chosen as an algorithm to
+#'   use, its results are excluded from the rest of the consensus clusters. This
+#'   is because there is no guarantee that the cluster assignment will have
+#'   every sample clustered; more often than not there will be noise points or
+#'   outliers. In addition, the number of distinct clusters may not even be
+#'   equal to `nk`.
 #'
 #' @param data data matrix with rows as samples and columns as variables
 #' @param nk number of clusters (k) requested; can specify a single integer or a
@@ -41,11 +41,8 @@
 #'   clustering. Must be any number of the following: "nmf", "hc", "diana",
 #'   "km", "pam", "ap", "sc", "gmm", "block", "som", "cmeans", "hdbscan". A
 #'   custom clustering algorithm can be used.
-#' @param nmf.method specify NMF-based algorithms to run. By default both
-#'   "scd" and "lee" algorithms are called. See [NNLM::nnmf()] for details.
-#' @param nmf.loss specify loss function to use for NMF. Either "mse" for mean
-#'   square error (default) or "mkl" for mean KL-divergence. See [NNLM::nnmf()]
-#'   for details.
+#' @param nmf.method specify NMF-based algorithms to run. By default the
+#'   "brunet" and "lee" algorithms are called. See [NMF::nmf()] for details.
 #' @param xdim x dimension of the SOM grid
 #' @param ydim y dimension of the SOM grid
 #' @param rlen the number of times the complete data set will be presented to
@@ -102,8 +99,7 @@
 #' str(cc)
 consensus_cluster <- function(data, nk = 2:4, p.item = 0.8, reps = 1000,
                               algorithms = NULL,
-                              nmf.method = c("scd", "lee"),
-                              nmf.loss = c("mse", "mkl"),
+                              nmf.method = c("brunet", "lee"),
                               xdim = NULL, ydim = NULL, rlen = 200,
                               alpha = c(0.05, 0.01), minPts = 5,
                               distance = "euclidean",
@@ -114,7 +110,6 @@ consensus_cluster <- function(data, nk = 2:4, p.item = 0.8, reps = 1000,
                               min.var = 1, progress = TRUE,
                               seed.nmf = 123456, seed.data = 1,
                               file.name = NULL, time.saved = FALSE) {
-  nmf.loss <- match.arg(nmf.loss)
   prep.data <- match.arg(prep.data)
   if (prep.data == "full")
     data <- prepare_data(data, scale = scale, type = type, min.var = min.var)
@@ -140,7 +135,7 @@ consensus_cluster <- function(data, nk = 2:4, p.item = 0.8, reps = 1000,
   # Argument lists: Common, NMF, Distance, Other
   cargs <- dplyr::lst(data, nk, p.item, reps, seed.data, prep.data, scale, type,
                       min.var, pb, lalg, n)
-  nargs <- dplyr::lst(algs = algs$NALG, nmf.method, nmf.loss, seed.nmf)
+  nargs <- dplyr::lst(algs = algs$NALG, nmf.method, seed.nmf)
   dargs <- dplyr::lst(algs = algs$DALG, distance)
   oargs <- dplyr::lst(algs = algs$OALG, xdim, ydim, rlen, alpha, minPts)
   args <- purrr::map(list(nargs, dargs, oargs), ~ c(cargs, .))
@@ -170,7 +165,7 @@ cc <- function(fun, args) {
 
 #' Cluster NMF-based algorithms
 #' @noRd
-cc_nmf <- function(data, nk, p.item, reps, algs, nmf.method, nmf.loss, seed.nmf,
+cc_nmf <- function(data, nk, p.item, reps, algs, nmf.method, seed.nmf,
                    seed.data, prep.data, scale, type, min.var, pb, lalg, n) {
   alg <- paste(toupper(algs), Hmisc::capitalize(nmf.method), sep = "_")
   arr <- init_array(data, reps, alg, nk)
@@ -192,8 +187,7 @@ cc_nmf <- function(data, nk, p.item, reps, algs, nmf.method, nmf.loss, seed.nmf,
           pb$tick(tokens = list(num = j, den = sum(lalg), alg = alg[j],
                                 k = nk[k]))
         }
-        arr[ind.new, i, j, k] <-
-          nmf(x, nk[k], nmf.method[j], nmf.loss, seed.nmf)
+        arr[ind.new, i, j, k] <- nmf(x, nk[k], nmf.method[j], seed.nmf)
       }
     }
   }
